% Fixed point iteration
% Inputs
%  g	 contraction (function taking a real argument and returning a real
%        number) 
%  x0    initial iterate
%  maxit maximum number of iterations
%  tol   tolerance for two consecutive iterates
% 
% Outputs
%  xs    vector containing the iterates
function xs = fixedpoint(g,x0,maxit,tol)

 % TO BE COMPLETED
